@@ -1,13 +1,13 @@
 #!/usr/bin/env python3
 # MIT licensed
-# Copyright (c) 2013-2020 lilydjwg <lilydjwg@gmail.com>, et al.
+# Copyright (c) 2013-2022 lilydjwg <lilydjwg@gmail.com>, et al.
 
 from __future__ import annotations
 
 import sys
 import argparse
 import asyncio
-from typing import Coroutine
+from typing import Coroutine, Tuple
 from pathlib import Path
 
 import structlog
@@ -25,6 +25,8 @@ def main() -> None:
                       help='use specified keyfile (override the one in configuration file)')
   parser.add_argument('-t', '--tries', default=1, type=int, metavar='N',
                       help='try N times when network errors occur')
+  parser.add_argument('--failures', action='store_true',
+                      help='exit with code 3 if failures / errors happen during checking')
   parser.add_argument('-e', '--entry', type=str,
                       help='only execute on specified entry (useful for debugging)')
   core.add_common_arguments(parser)
@@ -76,17 +78,18 @@ def main() -> None:
   result_coro = core.process_result(oldvers, result_q, entry_waiter)
   runner_coro = core.run_tasks(futures)
 
-  # asyncio.run doesn't work because it always creates new eventloops
-  loop = asyncio.get_event_loop()
-  newvers = loop.run_until_complete(run(result_coro, runner_coro))
+  newvers, has_failures = asyncio.run(run(result_coro, runner_coro))
 
   if options.ver_files is not None:
     core.write_verfile(options.ver_files[1], newvers)
 
+  if args.failures and has_failures:
+    sys.exit(3)
+
 async def run(
-  result_coro: Coroutine[None, None, VersData],
+  result_coro: Coroutine[None, None, Tuple[VersData, bool]],
   runner_coro: Coroutine[None, None, None],
-) -> VersData:
+) -> Tuple[VersData, bool]:
   result_fu = asyncio.create_task(result_coro)
   runner_fu = asyncio.create_task(runner_coro)
   await runner_fu
